=========
Changelog
=========

Version 1.12.0
--------------


Version 1.11.0
--------------


Version 1.10.0
--------------


Version 1.9.0
-------------

- 37ce7e1 Update Eiffellib version to latest. (#10)

Version 1.8.0
-------------

- 96d02ae Make the logging module more configurable and easier to use (#9)

Version 1.7.0
-------------

- ecfbe47 Add default identifier
- 2b2eadc Adding a logging module to ETOS library (#8)

Version 1.6.0
-------------


Version 1.5.0
-------------


Version 1.4.0
-------------


Version 1.3.0
-------------


Version 1.2.0
-------------


Version 1.1.0
-------------

- f03b3e1 Update README.rst (#7)
- 7376a7e Add CODEOWNERS file with etos maintainers (#6)
- 19fa706 Update README.rst (#5)
